scan_features

Function scan_features 

pub fn scan_features(
    base_path: &Path,
    config: ScanConfig<'_>,
) -> Result<Vec<Feature>>
Scan features in a directory with the given configuration

Arguments

  • base_path - The directory to scan for features
  • config - Configuration options for the scan

Returns

A vector of Feature objects representing the discovered features

Example

use features_cli::scan::{scan_features, ScanConfig};
use std::path::Path;

let current_dir = std::env::current_dir().unwrap();
let config = ScanConfig::new(&current_dir)
    .skip_changes(false)
    .with_coverage(true);

let features = scan_features(Path::new("./src"), config).unwrap();
println!("Found {} features", features.len());